package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.dao.SysconfigMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.ISysconfig;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.InstanceUtil;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/SysconfigService.class */
public class SysconfigService implements ISysconfig {
    private SysconfigMapper sysconfigMapper = (SysconfigMapper) InstanceUtil.newDaoInstance(SysconfigMapper.class);

    public int searchCount(HttpSession session, String name) throws Exception {
        return this.sysconfigMapper.searchCount(name, DataRule.getRuleWhere(session, "t_sysscan_config"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, Integer offset, Integer limit) throws Exception {
        return this.sysconfigMapper.search(name, offset, limit, DataRule.getRuleWhere(session, "t_sysscan_config"));
    }

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer count = this.sysconfigMapper.getCountSysById(id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("此模板已被引用，请在系统扫描中移除引用关系！");
        }
        Integer vcount = Integer.valueOf(this.sysconfigMapper.delete(id, version, DataRule.getRuleWhere(session, "t_sysscan_config")));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public void insert(HttpSession session, String name, String config) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.sysconfigMapper.getCountByName(name, (Integer) null, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在！");
        }
        this.sysconfigMapper.insert(name, config, uid);
    }

    public void update(HttpSession session, Integer id, String name, String config, Integer version) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.sysconfigMapper.getCountByName(name, id, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在");
        }
        Integer vcount = Integer.valueOf(this.sysconfigMapper.update(id, name, config, version, DataRule.getRuleWhere(session, "t_sysscan_config"), uid));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public Map<String, Object> getTemplateById(Integer id) throws Exception {
        return this.sysconfigMapper.getTemplateById(id);
    }

    public List<Map<String, Object>> getSysconfig(HttpSession session) throws Exception {
        return this.sysconfigMapper.getSysconfig(DataRule.getRuleWhere(session, "t_sysscan_config"));
    }

    public Map<String, Object> getDefaultSysConf(HttpSession session) throws Exception {
        return this.sysconfigMapper.getDefaultSysConf(DataRule.getRuleWhere(session, "t_sysscan_config"));
    }
}
